;;; Guile-LZMA
;;; Copyright © 2021 Timothy Sample <samplet@ngyro.com>
;;;
;;; This file is part of Guile-LZMA.
;;;
;;; Guile-LZMA is free software: you can redistribute it and/or modify
;;; it under the terms of the GNU General Public License as published by
;;; the Free Software Foundation, either version 3 of the License, or
;;; (at your option) any later version.
;;;
;;; Guile-LZMA is distributed in the hope that it will be useful,
;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;;; GNU General Public License for more details.
;;;
;;; You should have received a copy of the GNU General Public License
;;; along with Guile-LZMA.  If not, see <http://www.gnu.org/licenses/>.

(define-module (lzma config)
  #:export (%lzma-library-path))

(define %lzma-library-path "/usr/lib/liblzma")
